@@ -25,6 +25,8 @@ class OutgoingWebmentionException(WebmentionsException):
 class WebmentionsConfigurationException(WebmentionsException):
     """Base class for an error related to `django-wm` setup."""
 
+    pass
+
 
 class BadUrlConfig(WebmentionsConfigurationException):
     """URL resolution completed but did not include required data."""
@@ -62,6 +64,12 @@ class SourceDoesNotLink(IncomingWebmentionException):
     pass
 
 
+class RejectedByConfig(IncomingWebmentionException):
+    """The mention is being rejected due to the current settings configuration."""
+
+    pass
+
+
 class NoModelForUrlPath(IncomingWebmentionException):
     """URL resolved to a `urlpattern` which did not include `model_name` kwarg."""
 
